@@ -1,30 +1,29 @@
 /* arc sin, cosine, tan2 and sqrt that will NOT fail */
-#ifndef lint
-static const char SCCSID[]="@(#)aasincos.c	4.6	93/12/12	GIE	REL";
-#endif
 #include <projects.h>
 #define ONE_TOL	 1.00000000000001
 #define TOL	0.000000001
 #define ATOL 1e-50
-	double
-aasin(double v) {
-	double av;
 
+	double
+aasin(projCtx ctx,double v) {
+	double av;
+        
 	if ((av = fabs(v)) >= 1.) {
 		if (av > ONE_TOL)
-			pj_errno = -19;
-		return (v < 0. ? -HALFPI : HALFPI);
+                        pj_ctx_set_errno( ctx, -19 );
+		return (v < 0. ? -M_HALFPI : M_HALFPI);
 	}
 	return asin(v);
 }
+
 	double
-aacos(double v) {
+aacos(projCtx ctx, double v) {
 	double av;
 
 	if ((av = fabs(v)) >= 1.) {
 		if (av > ONE_TOL)
-			pj_errno = -19;
-		return (v < 0. ? PI : 0.);
+                        pj_ctx_set_errno( ctx, -19 );
+		return (v < 0. ? M_PI : 0.);
 	}
 	return acos(v);
 }
