@@ -55,7 +55,7 @@ do_geod(void) {
 	}
 	printLL(phil, laml); putchar('\n');
 }
-	void static	/* file processing function */
+	static void	/* file processing function */
 process(FILE *fid) {
 	char line[MAXLINE+3], *s;
 
@@ -87,8 +87,8 @@ process(FILE *fid) {
 		}
 		if (!*s && (s > line)) --s; /* assumed we gobbled \n */
 		if (pos_azi) {
-			if (al12 < 0.) al12 += TWOPI;
-			if (al21 < 0.) al21 += TWOPI;
+			if (al12 < 0.) al12 += M_TWOPI;
+			if (al21 < 0.) al21 += M_TWOPI;
 		}
 		if (fullout) {
 			printLL(phi1, lam1); TAB;
