@@ -1,7 +1,4 @@
 /* general forward projection */
-#ifndef lint
-static const char SCCSID[]="@(#)pj_fwd.c	4.4	93/06/12	GIE	REL";
-#endif
 #define PJ_LIB__
 #include <projects.h>
 #include <errno.h>
@@ -12,26 +9,38 @@ pj_fwd(LP lp, PJ *P) {
 	double t;
 
 	/* check for forward and latitude or longitude overange */
-	if ((t = fabs(lp.phi)-HALFPI) > EPS || fabs(lp.lam) > 10.) {
+	if ((t = fabs(lp.phi)-M_HALFPI) > EPS || fabs(lp.lam) > 10.) {
 		xy.x = xy.y = HUGE_VAL;
-		pj_errno = -14;
+		pj_ctx_set_errno( P->ctx, -14);
 	} else { /* proceed with projection */
-		errno = pj_errno = 0;
+                P->ctx->last_errno = 0;
+                pj_errno = 0;
+                errno = 0;
+
 		if (fabs(t) <= EPS)
-			lp.phi = lp.phi < 0. ? -HALFPI : HALFPI;
+			lp.phi = lp.phi < 0. ? -M_HALFPI : M_HALFPI;
 		else if (P->geoc)
 			lp.phi = atan(P->rone_es * tan(lp.phi));
 		lp.lam -= P->lam0;	/* compute del lp.lam */
 		if (!P->over)
 			lp.lam = adjlon(lp.lam); /* adjust del longitude */
-		xy = (*P->fwd)(lp, P); /* project */
-		if (pj_errno || (pj_errno = errno))
+
+                /* Check for NULL pointer */
+                if (P->fwd != NULL)
+                {
+		    xy = (*P->fwd)(lp, P); /* project */
+		    if ( P->ctx->last_errno )
 			xy.x = xy.y = HUGE_VAL;
-		/* adjust for major axis and easting/northings */
-		else {
+		    /* adjust for major axis and easting/northings */
+		    else {
 			xy.x = P->fr_meter * (P->a * xy.x + P->x0);
 			xy.y = P->fr_meter * (P->a * xy.y + P->y0);
-		}
+		    }
+                }
+                else
+                {
+                    xy.x = xy.y = HUGE_VAL;
+                }
 	}
 	return xy;
 }
