@@ -1,7 +1,4 @@
 /* <<<< Cartographic projection filter program >>>> */
-#ifndef lint
-static const char SCCSID[]="@(#)proj.c	4.12	95/09/23	GIE	REL";
-#endif
 #include "projects.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,7 +42,7 @@ postscale = 0;
 *oform = (char *)0,	/* output format for x-y or decimal degrees */
 *oterr = "*\t*",	/* output line for unprojectable input */
 *usage =
-"%s\nusage: %s [ -beEfiIlormsStTvVwW [args] ] [ +opts[=arg] ] [ files ]\n";
+"%s\nusage: %s [ -bCeEfiIlormsStTvVwW [args] ] [ +opts[=arg] ] [ files ]\n";
 	static struct FACTORS
 facs;
 	static double
@@ -141,12 +138,14 @@ process(FILE *fid) {
 			}
 		}
 		if (dofactors) /* print scale factor data */
+                {
 			if (!facs_bad)
 				(void)printf("\t<%g %g %g %g %g %g>",
 					facs.h, facs.k, facs.s,
 					facs.omega * RAD_TO_DEG, facs.a, facs.b);
 			else
 				(void)fputs("\t<* * * * * *>", stdout);
+                }
 		(void)fputs(bin_in ? "\n" : s, stdout);
 	}
 }
@@ -159,7 +158,7 @@ vprocess(FILE *fid) {
 	if (!oform)
 		oform = "%.3f";
 	if (bin_in || bin_out)
-		emess(1,"binary I/O not available in -V option");	
+		emess(1,"binary I/O not available in -V option");
 	for (;;) {
 		++emess_dat.File_line;
 		if (!(s = fgets(line, MAX_LINE, fid)))
@@ -250,7 +249,7 @@ int main(int argc, char **argv) {
     FILE *fid;
     int pargc = 0, iargc = argc, eargc = 0, c, mon = 0;
 
-    if (emess_dat.Prog_name = strrchr(*argv,DIR_CHAR))
+    if ( (emess_dat.Prog_name = strrchr(*argv,DIR_CHAR)) != NULL)
         ++emess_dat.Prog_name;
     else emess_dat.Prog_name = *argv;
     inverse = ! strncmp(emess_dat.Prog_name, "inv", 3);
@@ -268,6 +267,9 @@ int main(int argc, char **argv) {
               case 'b': /* binary I/O */
                 bin_in = bin_out = 1;
                 continue;
+              case 'C': /* Check - run internal regression tests */
+                return pj_run_selftests (very_verby);
+                continue;
               case 'v': /* monitor dump of initialization */
                 mon = 1;
                 continue;
@@ -301,8 +303,8 @@ int main(int argc, char **argv) {
                     char *str;
 
                     for (lp = pj_get_list_ref() ; lp->id ; ++lp) {
-                        if( strcmp(lp->id,"latlong") == 0 
-                            || strcmp(lp->id,"longlat") == 0 
+                        if( strcmp(lp->id,"latlong") == 0
+                            || strcmp(lp->id,"longlat") == 0
                             || strcmp(lp->id,"geocent") == 0 )
                             continue;
 
@@ -354,7 +356,7 @@ int main(int argc, char **argv) {
                 continue; /* artificial */
               case 'e': /* error line alternative */
                 if (--argc <= 0)
-                    noargument:			   
+                    noargument:
                 emess(1,"missing argument for -%c",*arg);
                 oterr = *++argv;
                 continue;
@@ -365,7 +367,7 @@ int main(int argc, char **argv) {
               case 'm': /* cartesian multiplier */
                 if (--argc <= 0) goto noargument;
                 postscale = 1;
-                if (!strncmp("1/",*++argv,2) || 
+                if (!strncmp("1/",*++argv,2) ||
                     !strncmp("1:",*argv,2)) {
                     if((fscale = atof((*argv)+2)) == 0.)
                         goto badscale;
